@@ -148,6 +148,9 @@ class Chord(object):
     def with_timing(self, start_time=None, end_time=None, length=None):
         return Chord(notes = [ x.with_timing(start_time=start_time, end_time=end_time, length=length) for x in self.notes ], from_scale=self.from_scale)
 
+    def scale_transpose(self, scale_obj, steps):
+        return Chord(notes = [ x.scale_transpose(scale_obj, steps) for x in self.notes ], from_scale=self.from_scale)
+
     def _chordify(self):
         """
         Internal method.
@@ -170,9 +173,7 @@ class Chord(object):
     def invert(self, amount=1, octaves=1):
         """
         Inverts a chord.
-        ex: chord("c4 major").invert() -> chord(["E4","G4","C5"])
         """
-        # TODO: this should be surfaced in mod expressions, and if used with a note, ignored
         new_chord = self.copy()
         if amount >= 1:
             new_chord.notes[0] = new_chord.notes[0].transpose(octaves=octaves)
