@@ -23,8 +23,9 @@ class Transform(NewReferenceObject, Directionable):
     __slots__ = [ 'name', 'slots', 'current_slots', 'octave_slots', 'divide', 'applies_to', 'obj_id',
                   'direction', 'current_direction', '_iterator', '_mod', '_slot_mods', '_repeat_processor' ]
 
-    def __init__(self, name=None, slots=None, octave_slots=None, divide=1, obj_id=None,
+    def __init__(self, song=None, name=None, slots=None, octave_slots=None, divide=1, obj_id=None,
                  applies_to=None, _repeat_processor=False, direction=FORWARD):
+
         self.name = name
         self.slots = slots
         self.divide = divide
@@ -32,7 +33,7 @@ class Transform(NewReferenceObject, Directionable):
         self.applies_to = applies_to
         self.obj_id = obj_id
         self._repeat_processor = _repeat_processor
-        self._mod = ModExpression(defer=False)
+        self._mod = ModExpression(song=song, defer=False) # song may be None, will update later
         self._slot_mods = roller(slots)
         self.direction = direction
         self.current_direction = direction
